@@ -14,6 +14,7 @@ if TYPE_CHECKING:
     from .nd2_reader import ND2Reader  # noqa: F401
     from .ome_tiff_reader import OmeTiffReader  # noqa: F401
     from .reader import Reader
+    from .tiff_glob_reader import TiffGlobReader  # noqa: F401
     from .tiff_reader import TiffReader  # noqa: F401
 
 
@@ -27,6 +28,7 @@ _READERS = (
     ".nd2_reader.ND2Reader",
     ".ome_tiff_reader.OmeTiffReader",
     ".tiff_reader.TiffReader",
+    ".tiff_glob_reader.TiffGlobReader",
 )
 _LOOKUP = {k.rsplit(".", 1)[-1]: k for k in _READERS}
 __all__ = list(_LOOKUP)
