@@ -9,6 +9,7 @@ import dask.array as da
 import numpy as np
 import xarray as xr
 from fsspec.spec import AbstractFileSystem
+from ome_types import OME
 
 from .. import constants, exceptions, transforms, types
 from ..dimensions import DEFAULT_DIMENSION_ORDER, DimensionNames, Dimensions
@@ -67,7 +68,6 @@ class Reader(ABC):
         supported: bool
             Boolean value indicating if the file is supported by the reader.
         """
-        pass
 
     @classmethod
     def is_supported_image(cls, image: types.ImageLike, **kwargs: Any) -> bool:
@@ -152,7 +152,6 @@ class Reader(ABC):
 
         >>> for i in range(len(image.scenes))
         """
-        pass
 
     @property
     def current_scene(self) -> str:
@@ -263,7 +262,6 @@ class Reader(ABC):
         * If a channel dimension is present, please populate the channel dimensions
         coordinate array the respective channel coordinate values.
         """
-        pass
 
     @abstractmethod
     def _read_immediate(self) -> xr.DataArray:
@@ -282,7 +280,6 @@ class Reader(ABC):
         * If a channel dimension is present, please populate the channel dimensions
         coordinate array the respective channel coordinate values.
         """
-        pass
 
     def _get_stitched_dask_mosaic(self) -> xr.DataArray:
         """
@@ -697,6 +694,23 @@ class Reader(ABC):
 
         return self._metadata
 
+    @property
+    def ome_metadata(self) -> OME:
+        """
+        Returns
+        -------
+        metadata: OME
+            The original metadata transformed into the OME specfication.
+            This likely isn't a complete transformation but is guarenteed to
+            be a valid transformation.
+
+        Raises
+        ------
+        NotImplementedError
+            No metadata transformer available.
+        """
+        raise NotImplementedError()
+
     @property
     def channel_names(self) -> Optional[List[str]]:
         """
